@@ -2,7 +2,7 @@
 ## Use of this source code is governed by a BSD-style license that can be
 ## found in the COPYING file.
 
-""" Collection of parser fonctions for various actions
+""" Collection of parser fonctions for qibuild actions
 """
 
 import os
@@ -43,8 +43,6 @@ def build_parser(parser):
     qisys.parsers.worktree_parser(parser)
     job_parser(parser, group=group)
     build_type_parser(parser, group=group)
-    group.add_argument("-G", "--cmake-generator", action="store",
-        help="Specify the CMake generator")
     group.add_argument("-c", "--config",
         help="The configuration to use. "
              "It should be the name of a toolchain, or \"system\"")
@@ -53,6 +51,8 @@ def build_parser(parser):
         help="A profile to use. "
              "It can appear several times. "
              "It should match a declaration in .qi/qibuild.xml")
+    group.add_argument("--verbose-make", action="store_true", default=False,
+                       help="Print the executed commands while building")
 
 def project_parser(parser, positional=True):
     """Parser settings for every action using several build projects."""
@@ -152,8 +152,9 @@ def get_build_config(build_worktree, args):
     build_config.build_type = args.build_type
     if args.profiles:
         build_config.profiles = args.profiles
-    if args.cmake_generator:
+    if hasattr(args, "cmake_generator"):
         build_config.cmake_generator = args.cmake_generator
+    build_config.verbose_make = args.verbose_make
     if hasattr(args, "cmake_flags") and args.cmake_flags:
         # should be a list a strings looking like key=value
         user_flags = list()
