@@ -33,7 +33,11 @@ class Snapshot(object):
         except TypeError:
             fp = input_file
         for line in fp:
-            (src, sha1) = line.split(":")
+            try:
+                (src, sha1) = line.split(":")
+            except ValueError:
+                ui.error("could not parse", line)
+                continue
             src = src.strip()
             sha1 = sha1.strip()
             self.refs[src] = sha1
@@ -64,4 +68,4 @@ def load_snapshot(git_worktree, input_path):
     for (src, ref) in snapshot.refs.iteritems():
         ui.info("Loading", src)
         git_project = git_worktree.get_git_project(src, raises=True)
-        qisrc.reset.clever_reset_ref(git_project, ref)
\ No newline at end of file
+        qisrc.reset.clever_reset_ref(git_project, ref)
